@@ -1,7 +1,7 @@
 /*  
     VTun - Virtual Tunnel over TCP/IP network.
 
-    Copyright (C) 1998-2000  Maxim Krasnyansky <max_mk@yahoo.com>
+    Copyright (C) 1998-2008  Maxim Krasnyansky <max_mk@yahoo.com>
 
     VTun has been derived from VPPP package by Maxim Krasnyansky. 
 
@@ -17,7 +17,7 @@
  */
 
 /*
- * linkfd.c,v 1.4.2.15.2.2 2006/11/16 04:03:23 mtbishop Exp
+ * $Id: linkfd.c,v 1.13.2.3 2008/01/07 22:35:43 mtbishop Exp $
  */
 
 #include "config.h"
@@ -365,8 +365,12 @@ int linkfd(struct vtun_host *host)
 	lfd_add_mod(&lfd_lzo);
 
      if(host->flags & VTUN_ENCRYPT)
-	lfd_add_mod(&lfd_encrypt);
-
+       if(host->cipher == VTUN_LEGACY_ENCRYPT) {
+	 lfd_add_mod(&lfd_legacy_encrypt);
+       } else {
+	 lfd_add_mod(&lfd_encrypt);
+       }
+     
      if(host->flags & VTUN_SHAPE)
 	lfd_add_mod(&lfd_shaper);
 
