@@ -1,7 +1,7 @@
 /*  
     VTun - Virtual Tunnel over TCP/IP network.
 
-    Copyright (C) 1998-2000  Maxim Krasnyansky <max_mk@yahoo.com>
+    Copyright (C) 1998-2008  Maxim Krasnyansky <max_mk@yahoo.com>
 
     VTun has been derived from VPPP package by Maxim Krasnyansky. 
 
@@ -17,7 +17,7 @@
  */
 
 /*
- * vtun.h,v 1.7.2.6.2.6 2006/11/16 04:04:17 mtbishop Exp
+ * $Id: vtun.h,v 1.12.2.3 2008/01/07 22:36:07 mtbishop Exp $
  */ 
 
 #ifndef _VTUN_H
@@ -155,6 +155,8 @@ extern llist host_list;
 #define VTUN_ENC_AES256CFB	15
 #define VTUN_ENC_AES256OFB	16
 
+#define VTUN_LEGACY_ENCRYPT	999
+
 /* Mask to drop the flags which will be supplied by the server */
 #define VTUN_CLNT_MASK  0xf000
 
